@@ -3,7 +3,7 @@ import hmac
 from collections import OrderedDict
 from hashlib import sha256
 
-from rebotics_sdk.providers import ReboticsBaseProvider, remote_service
+from rebotics_sdk.providers import ReboticsBaseProvider, remote_service, PageResult
 
 
 class FVMProvider(ReboticsBaseProvider):
@@ -13,8 +13,8 @@ class FVMProvider(ReboticsBaseProvider):
         self.secret_key = None
 
     def set_retailer_identifier(self, codename: str, secret_key: str) -> None:
-        self.headers['HTTP_X_RETAILER_CODENAME'] = codename
-        self.headers['HTTP_X_RETAILER_SECRET_KEY'] = secret_key
+        self.headers['x-retailer-codename'] = codename
+        self.headers['x-retailer-secret-key'] = secret_key
         self.codename = codename
         self.secret_key = secret_key
 
@@ -57,8 +57,11 @@ class FVMProvider(ReboticsBaseProvider):
     def get_preview_permalink(self, barcode):
         assert barcode.isdigit()
         url = self.build_url(self.session.url.format(barcode=barcode))
-        token = self.generate_token(url)
-        return f'{url}?token={token}&codename={self.codename}'
+        if self.secret_key and self.codename:
+            token = self.generate_token(url)
+            return f'{url}?token={token}&codename={self.codename}'
+        else:
+            return url
 
     def generate_token(self, path):
         # You need this function to generate a token to use it, for example, in the authentication
@@ -82,6 +85,14 @@ class FVMProvider(ReboticsBaseProvider):
             'image_url': image_url
         })
 
+    @remote_service('/api/products/')
+    def get_products_list(self, page=1, page_size=100):
+        params = {
+            'page': page,
+            'page_size': page_size,
+        }
+        return PageResult(self.session.get(params=params))
+
     @remote_service('/api/products/')
     def create_product(self, code, title):
         return self.session.post(json={
